@@ -33,6 +33,9 @@ import argparse
 # Support deprecation warnings:
 import warnings
 
+# Support split
+import shlex
+
 # Support static type checks:
 from typing import Optional, Union, List, Callable, Dict, Tuple
 
@@ -260,7 +263,7 @@ def cli(arguments: Union[str, List[str]] = "",
        ----------
        arguments : str or list
            Command line arguments. If a string is passed, it is first split using
-           spaces as separators.
+           shlex.split()
 
        prog : str
            Name of the calling program. It is used to build help texts. **Mostly for internal use**.
@@ -287,7 +290,7 @@ def cli(arguments: Union[str, List[str]] = "",
 
     # allow passing a single string
     if isinstance(arguments, str):
-        arguments = arguments.split()
+        arguments = shlex.split(arguments)
 
     func = None
 
@@ -481,6 +484,7 @@ def _jrun(**kargs):
 @arg("--python-exec",
      help="remote python executable (e.g. module load python3 python-home; python)",
      default="python")
+@arg("--server-url", help="URL on server (default: choose interactively)", default="")
 @arg("--open-cmd", help="open command (detected automatically by default)", default="")
 def _jremote(**kargs):
     """
@@ -575,6 +579,7 @@ def _notify(**kargs):
 @arg("--python-exec", help="python executable", default="")
 @arg("--detach", help="detach screen", action="store_true")
 @arg("--unique", help="allow only one screen with this socket", action="store_true")
+@arg("--window", help="run a new window within the same screen", action="store_true")
 @arg("--period", help="period (seconds)", default=3600, type=int)
 @arg("--max-times", help="maximum number of calls", default=None, type=int)
 def _cron(**kargs):
