@@ -74,10 +74,12 @@ try:
     # slack client 3
     from slack_sdk import WebClient
     from slack_sdk.web.base_client import SlackResponse
+    from slack_sdk.errors import SlackApiError
 except ModuleNotFoundError:
     # slack client 2
     from slack import WebClient
     from slack.web.base_client import SlackResponse
+    from slack.errors import SlackApiError
 
 from . import coretools
 
@@ -86,16 +88,16 @@ from typing import cast
 _organization="bussilab"  # this is hardcoded for now
 
 def _parse_url(url: str):
-    if re.match(r"^https://.*\.slack\.com/archives/.*",url):
+    if re.match(r"^https://[^/]*\.slack\.com/archives/.*",url):
         organization = re.sub(r"^https://","", re.sub(r"\.slack\.com/archives/.*","",url))
-        url=re.sub(r"^https://.*\.slack\.com/archives/","",url)
+        url=re.sub(r"^https://[^/]*\.slack\.com/archives/","",url)
         url=url[:-6]+"."+url[-6:]
         channel=re.sub("/p.*","",url)
         ts=re.sub(".*/p","",url)
         return { "type":"message", "ts":ts, "channel":channel, "organization":organization }
-    if re.match(r"^https://.*\.slack\.com/files/.*",url):
+    if re.match(r"^https://[^/]*\.slack\.com/files/.*",url):
         organization = re.sub(r"^https://","", re.sub(r"\.slack\.com/files/.*","",url))
-        url=re.sub(r"^https://.*\.slack\.com/files/","",url)
+        url=re.sub(r"^https://[^/]*\.slack\.com/files/","",url)
         user=re.sub("/.*","",url)
         id=re.sub("^"+user+"/","",url)
         id=re.sub("/.*","",id)
@@ -203,9 +205,9 @@ def notify(message: str = "",
             if config is None:
                 config = coretools.config()
             channel=config["notify"]["channel"]
-        if re.match(r"^https://.*\.slack\.com/archives/.*", channel):
+        if re.match(r"^https://[^/]*\.slack\.com/archives/.*", channel):
             organization = re.sub("^https://","", re.sub(r"\.slack\.com/archives/.*","",channel))
-            channel=re.sub(r"^https://.*\.slack\.com/archives/","",channel)
+            channel=re.sub(r"^https://[^/]*\.slack\.com/archives/","",channel)
         else:
             # this is needed to set organization correctly (so as to build the
             # proper link) when passing the name of a channel
@@ -244,7 +246,7 @@ def notify(message: str = "",
         footer_text += " by "+ os.environ['USER']
         footer_text += " at " + socket.gethostname() +'\n'
         footer_text += "pwd: " + os.getcwd() + '\n'
-        footer_text += '{}'.format(datetime.datetime.now())
+        footer_text += datetime.datetime.now().isoformat(timespec='milliseconds')
         blocks.append({
                           "type": "context",
                           "elements": [
@@ -288,7 +290,16 @@ def notify(message: str = "",
             file_title += message +" "
         if footer:
             file_title += footer_text
-        response = client.files_upload(file=file,title=file_title,channels=channel)
+
+        attempts=5
+        for i in range(attempts):
+            try:
+                response = client.files_upload(file=file,title=file_title,channels=channel)
+                break
+            except SlackApiError:
+                if(i+1==attempts):
+                    raise
+                print("retrying ...",i+1)
     else:
         response = client.chat_postMessage(
                    blocks=blocks,
